# rtml-distributions package

Sumary of the package

# Files 

- Binomialdistribution.py
- Gaussiandistribution.py
- Generaldistribution.py
- Setup.cfg
- README.md
- license.txt

# Instalation

'''
pip install distributions
'''
